@@ -5,7 +5,12 @@ import yaml, os
 ConfigKey = Literal["org"]
 
 
-XDG_CONFIG_HOME = os.getenv("XDG_CONFIG_HOME", Path.home() / ".config")
+XDG_CONFIG_HOME = Path(os.getenv("XDG_CONFIG_HOME", str(Path.home() / ".config")))
+SYM_CONFIG_HOME = XDG_CONFIG_HOME / "sym"
+
+
+def sym_config_file(file_name: str) -> Path:
+    return SYM_CONFIG_HOME / file_name
 
 
 class ConfigSchema(TypedDict, total=False):
@@ -19,7 +24,7 @@ class Config(MutableMapping[ConfigKey, Any]):
     config: Final[ConfigSchema]
 
     def __init__(self) -> None:
-        self.path = Path(XDG_CONFIG_HOME) / "sym" / "config.yml"
+        self.path = sym_config_file("config.yml")
         self.path.parent.mkdir(parents=True, exist_ok=True)
         try:
             config = cast(
